nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Acfgt

Enum Acfgt 

#[repr(u8)]
pub enum Acfgt { ACFGT_0 = 0, ACFGT_1 = 1, }

Variants



ACFGT_0 = 0

Configures “Less Than Threshold, Outside Range Not Inclusive and Inside Range Not Inclusive” functionality based on the values placed in the ADC_CV register.



ACFGT_1 = 1

Configures “Greater Than Or Equal To Threshold, Outside Range Inclusive and Inside Range Inclusive” functionality based on the values placed in the ADC_CV registers.

Implementations

Source

impl Acfgt

pub const fn from_bits(val: u8) -> Acfgt

pub const fn to_bits(self) -> u8