#[repr(u8)]pub enum Acfgt {
ACFGT_0 = 0,
ACFGT_1 = 1,
}Variants
ACFGT_0 = 0
Configures “Less Than Threshold, Outside Range Not Inclusive and Inside Range Not Inclusive” functionality based on the values placed in the ADC_CV register.
ACFGT_1 = 1
Configures “Greater Than Or Equal To Threshold, Outside Range Inclusive and Inside Range Inclusive” functionality based on the values placed in the ADC_CV registers.
Implementations